==> telegram-desktop_3.6.1+ds.orig.tar.xz: tdesktop-3.6.1-full/Telegram/ThirdParty/tgcalls/tgcalls/group/VideoStreamingPart.h <==
#ifndef TGCALLS_VIDEO_STREAMING_PART_H
#define TGCALLS_VIDEO_STREAMING_PART_H

#include "absl/types/optional.h"
#include <vector>
#include <stdint.h>

#include "api/video/video_frame.h"
#include "absl/types/optional.h"

#include "AudioStreamingPart.h"
#include "AudioStreamingPartInternal.h"

namespace tgcalls {

class VideoStreamingPartState;

struct VideoStreamingPartFrame {
    std::string endpointId;
    webrtc::VideoFrame frame;
    double pts = 0;
    double duration = 0.0;
    int index = 0;

    VideoStreamingPartFrame(std::string endpointId_, webrtc::VideoFrame const &frame_, double pts_, double duration_, int index_) :
    endpointId(endpointId_),
    frame(frame_),
    pts(pts_),
    duration(duration_),
    index(index_) {
    }
};

class VideoStreamingPart {
public:
    enum class ContentType {
        Audio,
        Video
    };
    
public:
    explicit VideoStreamingPart(std::vector<uint8_t> &&data, VideoStreamingPart::ContentType contentType);
    ~VideoStreamingPart();
    
    VideoStreamingPart(const VideoStreamingPart&) = delete;
    VideoStreamingPart(VideoStreamingPart&& other) {
        _state = other._state;
        other._state = nullptr;
    }
    VideoStreamingPart& operator=(const VideoStreamingPart&) = delete;
    VideoStreamingPart& operator=(VideoStreamingPart&&) = delete;

    absl::optional<VideoStreamingPartFrame> getFrameAtRelativeTimestamp(double timestamp);
    absl::optional<std::string> getActiveEndpointId() const;
    
    int getAudioRemainingMilliseconds();
    std::vector<AudioStreamingPart::StreamingPartChannel> getAudio10msPerChannel(AudioStreamingPartPersistentDecoder &persistentDecoder);
    
private:
    VideoStreamingPartState *_state = nullptr;
};

}

#endif

==> telegram-desktop_4.14.9+ds.orig.tar.xz: tdesktop-4.14.9-full/Telegram/ThirdParty/tgcalls/tgcalls/group/VideoStreamingPart.h <==
#ifndef TGCALLS_VIDEO_STREAMING_PART_H
#define TGCALLS_VIDEO_STREAMING_PART_H

#include "absl/types/optional.h"
#include <vector>
#include <stdint.h>

#include "api/video/video_frame.h"
#include "absl/types/optional.h"

#include "AudioStreamingPart.h"
#include "AudioStreamingPartInternal.h"

namespace tgcalls {

class VideoStreamingPartState;

struct VideoStreamingPartFrame {
    std::string endpointId;
    webrtc::VideoFrame frame;
    double pts = 0;
    int index = 0;

    VideoStreamingPartFrame(std::string endpointId_, webrtc::VideoFrame const &frame_, double pts_, int index_) :
    endpointId(endpointId_),
    frame(frame_),
    pts(pts_),
    index(index_) {
    }
};

class VideoStreamingPart {
public:
    enum class ContentType {
        Audio,
        Video
    };
    
public:
    explicit VideoStreamingPart(std::vector<uint8_t> &&data, VideoStreamingPart::ContentType contentType);
    ~VideoStreamingPart();
    
    VideoStreamingPart(const VideoStreamingPart&) = delete;
    VideoStreamingPart(VideoStreamingPart&& other) {
        _state = other._state;
        other._state = nullptr;
    }
    VideoStreamingPart& operator=(const VideoStreamingPart&) = delete;
    VideoStreamingPart& operator=(VideoStreamingPart&&) = delete;

    absl::optional<VideoStreamingPartFrame> getFrameAtRelativeTimestamp(double timestamp);
    absl::optional<std::string> getActiveEndpointId() const;
    bool hasRemainingFrames() const;
    
    int getAudioRemainingMilliseconds();
    std::vector<AudioStreamingPart::StreamingPartChannel> getAudio10msPerChannel(AudioStreamingPartPersistentDecoder &persistentDecoder);
    
private:
    VideoStreamingPartState *_state = nullptr;
};

}

#endif
